#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 lsp
version:              2.2.0.0
visibility:           public
id:                   lsp-2.2.0.0-KwTs0YLLLhs7xPAe9XbIIA
key:                  lsp-2.2.0.0-KwTs0YLLLhs7xPAe9XbIIA
license:              MIT
copyright:            Alan Zimmerman, 2016-2021
maintainer:           alan.zimm@gmail.com
author:               Alan Zimmerman
homepage:             https://github.com/haskell/lsp
synopsis:             Haskell library for the Microsoft Language Server Protocol
description:
    An implementation of the types, and basic message server to
    allow language implementors to support the Language Server
    Protocol for their specific language.

    An example of this is for Haskell via the Haskell Language
    Server, at https://github.com/haskell/haskell-language-server

category:             Development
abi:                  f1eba97fed7a8c2b20f12f304fcf3931
exposed:              True
exposed-modules:
    Language.LSP.Diagnostics, Language.LSP.Logging,
    Language.LSP.Protocol.Capabilities from lsp-types-2.0.2.0-7cSqO6IrOh32v20RLanVd:Language.LSP.Protocol.Capabilities,
    Language.LSP.Protocol.Lens from lsp-types-2.0.2.0-7cSqO6IrOh32v20RLanVd:Language.LSP.Protocol.Lens,
    Language.LSP.Protocol.Message from lsp-types-2.0.2.0-7cSqO6IrOh32v20RLanVd:Language.LSP.Protocol.Message,
    Language.LSP.Protocol.Types from lsp-types-2.0.2.0-7cSqO6IrOh32v20RLanVd:Language.LSP.Protocol.Types,
    Language.LSP.Server, Language.LSP.VFS

hidden-modules:
    Language.LSP.Server.Control Language.LSP.Server.Core
    Language.LSP.Server.Processing

import-dirs:          /usr/lib/ghc-9.6.6/site-local/lsp-2.2.0.0
library-dirs:         /usr/lib/ghc-9.6.6/site-local/lsp-2.2.0.0
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/lsp-2.2.0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-lsp
hs-libraries:         HSlsp-2.2.0.0-KwTs0YLLLhs7xPAe9XbIIA
depends:
    aeson-2.2.2.0-6c1DCPq2cjw7mSOIGM724W
    async-2.2.6-4Cg1cnm4CwuITQT2ZpqpLR
    attoparsec-0.14.4-GTUtxC0om9b2L4ZneXqrPT base-4.18.2.1
    bytestring-0.11.5.3 co-log-core-0.3.2.6-Ky7pdewrTtRF0xBcnL3uJF
    containers-0.6.7 data-default-0.7.1.3-EtVHsfbH5oIpJ9umzYHUz
    directory-1.3.8.5 exceptions-0.10.7 filepath-1.4.300.1
    hashable-1.4.7.0-29C6HO1kEzxKGOntKCwjk4
    lens-5.3.4-6KV9HDCdZf8JKhnHS7R55U
    lens-aeson-1.2.3-3IIGrpnqe4yLicZ2Hq6p0p
    lsp-types-2.0.2.0-7cSqO6IrOh32v20RLanVd mtl-2.3.1
    prettyprinter-1.7.1-H2rJD2WExIbcRy2n74kLf
    random-1.2.1.3-2gB92M9Bgui9EHhzBvR4Sg
    row-types-1.0.1.2-9K9rqgMFXvA1K9wpE5N4qU
    sorted-list-0.2.3.1-5TjWmSEdhi2Gz2We4VjKBx stm-2.5.1.0
    temporary-1.3-8tzbl8BGPCBG97dDrXyVPU text-2.0.2
    text-rope-0.3-7ueg5ltCm5LGZM5iJVn7fE transformers-0.6.1.0
    unliftio-core-0.2.1.0-6sOpIonHj8t5wIbPhWbPHY
    unordered-containers-0.2.20.1-Hsa9d2Ja6XgAATZt7ZTK9f
    uuid-1.3.16.1-F1RuB7kUsIt65NrC9mg3Rr

haddock-interfaces:   /usr/share/doc/haskell-lsp/html/lsp.haddock
haddock-html:         /usr/share/doc/haskell-lsp/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

